@@ -52,6 +52,10 @@ class Mace4Semigroups(SemigroupsDataset):
     >>> mace4_semigroups[0][0]
     tensor([[0, 0],
             [0, 0]])
+    >>> mace4_semigroups.get_table_from_output("not a mace4 output file")
+    Traceback (most recent call last):
+        ...
+    ValueError: wrong mace4 output file format!
     """
 
     _where_clause = "WHERE output LIKE '%Process % exit (max_models)%'"
@@ -112,7 +116,7 @@ class Mace4Semigroups(SemigroupsDataset):
         return row_count
 
     def load_data_from_mace_output(self) -> None:
-        """ loads data generated by ``mace4`` from an ``sqlite`` database """
+        """loads data generated by ``mace4`` from an ``sqlite`` database"""
         cursor = connect_to_db(self.root)
         row_count = self.get_additional_info(cursor)
         cursor.execute(f"SELECT output FROM mace_output {self._where_clause}")
@@ -120,4 +124,4 @@ class Mace4Semigroups(SemigroupsDataset):
         for _ in tqdm(range(row_count)):
             output = cursor.fetchone()[0]
             features.append(self.get_table_from_output(output))
-        self.tensors = (torch.stack(features),)
+        self.tensors = [torch.stack(features)]
